/*
 * Copyright (C) 2012-2013 Andy Spencer <andy753421@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdlib.h>
#include <signal.h>

#include "args.h"
#include "util.h"
#include "conf.h"
#include "date.h"
#include "cal.h"
#include "view.h"

/* Config parser */
static void on_config(const char *group, const char *name, const char *key, const char *value)
{
	view_config(group, name, key, value);
	cal_config(group, name, key, value);
}

/* Control-C handler, so we don't hose the therminal */
static void on_sigint(int signum)
{
	view_exit();
	exit(0);
}

/* Main */
int main(int argc, char **argv)
{
	/* Misc setup */
	signal(SIGINT, on_sigint);

	/* Configuration */
	args_setup(argc, argv);
	conf_setup(".lackeyrc", on_config);

	/* Initialize */
	args_init();
	util_init();
	conf_init();
	date_init();
	cal_init();

	/* Run view main */
	view_init();
	view_main();
	view_exit();

	return 0;
}
